@@ -6,17 +6,20 @@ import numpy as np
 from typing import Any, Dict, Optional, Text, List, Type, Union
 
 from rasa.nlu.tokenizers.spacy_tokenizer import POS_TAG_KEY
-from rasa.constants import DOCS_URL_COMPONENTS
+from rasa.shared.constants import DOCS_URL_COMPONENTS
 from rasa.nlu.components import Component
 from rasa.nlu.tokenizers.tokenizer import Token
 from rasa.nlu.tokenizers.tokenizer import Tokenizer
 from rasa.nlu.featurizers.featurizer import SparseFeaturizer
+from rasa.shared.nlu.training_data.features import Features
 from rasa.nlu.config import RasaNLUModelConfig
-from rasa.nlu.training_data import Message, TrainingData
-from rasa.nlu.constants import TOKENS_NAMES, TEXT, SPARSE_FEATURE_NAMES
+from rasa.shared.nlu.training_data.training_data import TrainingData
+from rasa.shared.nlu.training_data.message import Message
+from rasa.nlu.constants import TOKENS_NAMES, FEATURIZER_CLASS_ALIAS
+from rasa.shared.nlu.constants import TEXT, FEATURE_TYPE_SEQUENCE
+
 from rasa.nlu.model import Metadata
 import rasa.utils.io as io_utils
-import rasa.utils.train_utils as train_utils
 
 logger = logging.getLogger(__name__)
 
@@ -113,8 +116,9 @@ class LexicalSyntacticFeaturizer(SparseFeaturizer):
         # get all possible feature values
         all_features = []
         for example in training_data.training_examples:
-            tokens_without_cls = train_utils.tokens_without_cls(example)
-            all_features.append(self._tokens_to_features(tokens_without_cls))
+            tokens = example.get(TOKENS_NAMES[TEXT])
+            if tokens:
+                all_features.append(self._tokens_to_features(tokens))
 
         # build vocabulary of features
         feature_vocabulary = self._build_feature_vocabulary(all_features)
@@ -161,18 +165,23 @@ class LexicalSyntacticFeaturizer(SparseFeaturizer):
         features."""
         import scipy.sparse
 
-        # [:-1] to remove CLS token
-        tokens = message.get(TOKENS_NAMES[TEXT])[:-1]
+        tokens = message.get(TOKENS_NAMES[TEXT])
+        # this check is required because there might be training data examples without TEXT,
+        # e.g., `Message("", {action_name: "action_listen"})`
+        if tokens:
 
-        sentence_features = self._tokens_to_features(tokens)
-        one_hot_feature_vector = self._features_to_one_hot(sentence_features)
+            sentence_features = self._tokens_to_features(tokens)
+            one_hot_seq_feature_vector = self._features_to_one_hot(sentence_features)
 
-        sparse_features = scipy.sparse.coo_matrix(one_hot_feature_vector)
+            sequence_features = scipy.sparse.coo_matrix(one_hot_seq_feature_vector)
 
-        sparse_features = self._combine_with_existing_sparse_features(
-            message, sparse_features, feature_name=SPARSE_FEATURE_NAMES[TEXT]
-        )
-        message.set(SPARSE_FEATURE_NAMES[TEXT], sparse_features)
+            final_sequence_features = Features(
+                sequence_features,
+                FEATURE_TYPE_SEQUENCE,
+                TEXT,
+                self.component_config[FEATURIZER_CLASS_ALIAS],
+            )
+            message.add_features(final_sequence_features)
 
     def _tokens_to_features(self, tokens: List[Token]) -> List[Dict[Text, Any]]:
         """Convert words into discrete features."""
@@ -220,9 +229,8 @@ class LexicalSyntacticFeaturizer(SparseFeaturizer):
         """Convert the word features into a one-hot presentation using the indices
         in the feature-to-idx dictionary."""
 
-        # +1 for CLS token
-        one_hot_feature_vector = np.zeros(
-            [len(sentence_features) + 1, self.number_of_features]
+        one_hot_seq_feature_vector = np.zeros(
+            [len(sentence_features), self.number_of_features]
         )
 
         for token_idx, token_features in enumerate(sentence_features):
@@ -235,12 +243,9 @@ class LexicalSyntacticFeaturizer(SparseFeaturizer):
                     feature_idx = self.feature_to_idx_dict[feature_name][
                         feature_value_str
                     ]
-                    one_hot_feature_vector[token_idx][feature_idx] = 1
+                    one_hot_seq_feature_vector[token_idx][feature_idx] = 1
 
-        # set vector of CLS token to sum of everything
-        one_hot_feature_vector[-1] = np.sum(one_hot_feature_vector, axis=0)
-
-        return one_hot_feature_vector
+        return one_hot_seq_feature_vector
 
     def _get_feature_value(
         self,
