@@ -10,6 +10,7 @@ from rasa.utils.tensorflow.constants import (
     MARGIN,
     COSINE,
     INNER,
+    LINEAR_NORM,
     CROSS_ENTROPY,
 )
 from rasa.utils.tensorflow.exceptions import TFLayerConfigException
@@ -581,7 +582,7 @@ class DotProductLoss(tf.keras.layers.Layer):
                 ensure that similarity values are approximately bounded.
                 Used inside _loss_cross_entropy() only.
             model_confidence: Model confidence to be returned during inference.
-                Possible values - 'softmax', 'cosine' and 'inner'.
+                Possible values - 'softmax' and 'linear_norm'.
 
         Raises:
             LayerConfigException: When `similarity_type` is not one of 'cosine' or 'inner'.
@@ -729,16 +730,16 @@ class DotProductLoss(tf.keras.layers.Layer):
         Returns:
             similarity between input and label embeddings and model's prediction confidence for each label.
         """
-        # If model's prediction confidence is configured to be cosine similarity,
-        # then normalize embeddings to unit vectors.
-        if self.model_confidence == COSINE:
-            input_embeddings = tf.nn.l2_normalize(input_embeddings, axis=-1)
-            label_embeddings = tf.nn.l2_normalize(label_embeddings, axis=-1)
-
         similarities = self.sim(input_embeddings, label_embeddings, mask)
         confidences = similarities
         if self.model_confidence == SOFTMAX:
             confidences = tf.nn.softmax(similarities)
+        if self.model_confidence == LINEAR_NORM:
+            # Clip negative values to 0 and linearly normalize to bring the predictions in the range [0,1].
+            clipped_similarities = tf.nn.relu(similarities)
+            confidences = clipped_similarities / tf.reduce_sum(
+                clipped_similarities, axis=-1
+            )
         return similarities, confidences
 
     def _train_sim(
